@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2015 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2016 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -457,6 +457,11 @@ public slots:
      * @param parent parent Widget.
      */
     void showDetails(QWidget *parent = 0);
+    /*!
+     * Shows the details for the current song (if any).
+     * @param parent parent widget.
+     */
+    void showDetailsForCurrent(QWidget *parent = 0);
     /*!
      * Ensures that the current track is visible.
      */
@@ -490,13 +495,17 @@ public slots:
      */
     void setQueued(PlayListTrack* item);
     /*!
-     * Removes invalid items from playlist
+     * Removes invalid tracks from playlist
      */
     void removeInvalidTracks();
     /*!
-     * Removes duplicate items by URL.
+     * Removes duplicate tracks by URL.
      */
     void removeDuplicates();
+    /*!
+     * Removes invalid tracks and scans parent directories for the new files
+     */
+    void refresh();
     /*!
      * Removes all items from queue.
      */
